#[non_exhaustive]pub struct PlannerSchedule {
pub learn_cycles: usize,
pub eval_cycles: usize,
pub explore_epsilon: f64,
pub explore_gamma: f64,
}Expand description
Planner learn/eval schedule derived from a runtime specification.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.learn_cycles: usizeNumber of learning cycles.
eval_cycles: usizeNumber of evaluation cycles.
explore_epsilon: f64Extra exploration probability at learning step zero.
explore_gamma: f64Per-step exploration decay factor.
Implementations
Sourceimpl PlannerSchedule
impl PlannerSchedule
Sourcepub fn new(learn_cycles: usize, eval_cycles: usize) -> Self
pub fn new(learn_cycles: usize, eval_cycles: usize) -> Self
Construct a schedule with zero extra exploration.
Sourcepub fn from_runtime(runtime: &PlannerRuntimeSpec) -> Self
pub fn from_runtime(runtime: &PlannerRuntimeSpec) -> Self
Derive the semantic execution schedule from a compiled runtime spec.
Sourcepub fn extra_exploration(&self, step: usize) -> f64
pub fn extra_exploration(&self, step: usize) -> f64
Extra exploration probability at the given global planner step.